Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1558)

Unified Diff: components/exo/wayland/server.cc

Issue 2511273002: Decouple BrowserCompositorOutputSurface from BeginFrameSource. (Closed)
Patch Set: Another attempt to fix the crash Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/exo/wayland/server.cc
diff --git a/components/exo/wayland/server.cc b/components/exo/wayland/server.cc
index 7b3d47ed80040647c1ddc52cbfadf1d94d6f513a..fd1f75682ee6bd32c3d79d733f9a2662446dac15 100644
--- a/components/exo/wayland/server.cc
+++ b/components/exo/wayland/server.cc
@@ -1860,7 +1860,7 @@ void bind_remote_shell(wl_client* client,
// Implements VSync timing interface by monitoring a compositor for updates
// to VSync parameters.
-class VSyncTiming : public ui::CompositorVSyncManager::Observer {
+class VSyncTiming : public cc::VSyncObserver {
public:
~VSyncTiming() { vsync_manager_->RemoveObserver(this); }
@@ -1873,7 +1873,7 @@ class VSyncTiming : public ui::CompositorVSyncManager::Observer {
return vsync_timing;
}
// Overridden from ui::CompositorVSyncManager::Observer:
void OnUpdateVSyncParameters(base::TimeTicks timebase,
base::TimeDelta interval) override {
uint64_t timebase_us = timebase.ToInternalValue();
@@ -1873,7 +1873,7 @@ class VSyncTiming : public ui::CompositorVSyncManager::Observer {
return vsync_timing;
}
- // Overridden from ui::CompositorVSyncManager::Observer:
+ // Overridden from cc::VSyncObserver:
void OnUpdateVSyncParameters(base::TimeTicks timebase,
base::TimeDelta interval) override {

Powered by Google App Engine
This is Rietveld 408576698